@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Find the top repeated note phrases of a MIDI file
 
-our $VERSION = '0.0101';
+our $VERSION = '0.0102';
 
 use Moo;
 use strictures 2;
@@ -391,7 +391,7 @@ MIDI::Ngram - Find the top repeated note phrases of a MIDI file
 
 =head1 VERSION
 
-version 0.0101
+version 0.0102
 
 =head1 SYNOPSIS
 
@@ -399,6 +399,7 @@ version 0.0101
   my $mng = MIDI::Ngram->new(
     file    => 'eg/twinkle_twinkle.mid',
     size    => 3,
+    patches => [qw( 68 69 70 71 72 73 )],
     verbose => 1,
   );
   $mng->process;
@@ -425,7 +426,7 @@ The maximum number of phrases to play.  Default: 10
 
 =head2 bpm
 
-Beats per minute.  Default: 20
+Beats per minute.  Default: 100
 
 =head2 durations
 
@@ -460,7 +461,7 @@ Default: 0 (piano)
 
 =head2 shuffle_phrases
 
-Boolean.  Shuffle the phrases before playing them.  Default: 0
+Boolean.  Shuffle the non-weighted phrases before playing them.  Default: 0
 
 =head2 single
 
@@ -527,6 +528,10 @@ L<List::Util::WeightedChoice>
 
 L<Music::Note>
 
+L<MIDI::Simple>
+
+L<Music::Tempo>
+
 =head1 AUTHOR
 
 Gene Boggs <gene@cpan.org>
